---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: "Status: Review Needed, Type: Bug"
assignees: Stranger6667
---

**Checklist**

- [ ] I checked the [FAQ section](https://schemathesis.readthedocs.io/en/stable/faq.html#frequently-asked-questions) of the documentation
- [ ] I looked for similar issues in the [issue tracker](https://github.com/schemathesis/schemathesis/issues)

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. Run this command '...'
2. See error

If possible, please post a minimal version of your API schema that cause this behavior:

```yaml
{
    "openapi": "3.0.2"
    ... Add more here
}
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**

- OS: [e.g. Linux or Windows]
- Python version: [e.g. 3.7.2]
- Schemathesis version: [e.g. 2.4.1]
- Spec version: [e.g. Open API 3.0.2]

**Additional context**
Add any other context about the problem here.
